.. _roadmap_toplevel:

===========================
Stalker Development Roadmap
===========================

This section describes the direction Stalker is going.

Roadmap Based on Versions
=========================

Below you can find the roadmap based on the version

0.1.1:
------
 * A complete working set of models in SOM.
 * The SQLAlchemy integration to have the database part, tables and mappers.
 * Ability to extend SOM with new classes and database mappers and tables.

0.2.0:
------
 * Interactions with host programs (MAYA, NUKE, HOUDINI etc.)
 * PySide interfaces

0.3.0:
------
 * Web interface
 * Complete Project Management capabilities.
 * And new features that I can't really see right now.